#!/usr/bin/env sh
#
# CIS-LBK Recommendation Function
# ~/CIS-LBK/functions/recommendations/nix_ensure_source_routed_packets_not_accepted.sh
# 
# Name                Date       Description
# ------------------------------------------------------------------------------------------------
# Eric Pinnell       10/22/20    Recommendation "Ensure source routed packets are not accepted"
#
ensure_source_routed_packets_not_accepted()
{
	echo "- $(date +%d-%b-%Y' '%T) - Starting $RNA" | tee -a "$LOG" 2>> "$ELOG"
	test="" test1="" test2="" test3="" test4="" test5="" test6="" test7="" test8=""

	# Check net.ipv4.conf.all.accept_source_route
	# Check sysctl net.ipv4.conf.all.accept_source_route in the running config
	echo "- $(date +%d-%b-%Y' '%T) - Checking sysctl net.ipv4.conf.all.accept_source_route in the running config" | tee -a "$LOG" 2>> "$ELOG"
	if sysctl net.ipv4.conf.all.accept_source_route | grep -Eq '^net.ipv4.conf.all.accept_source_route\s*=\s*0\b'; then
		test1=passed
	else
		echo "- $(date +%d-%b-%Y' '%T) - Remediating net.ipv4.conf.all.accept_source_route in the running config" | tee -a "$LOG" 2>> "$ELOG"
		sysctl -w net.ipv4.conf.all.accept_source_route=0
		sysctl -w net.ipv4.route.flush=1
		sysctl net.ipv4.conf.all.accept_source_route | grep -Eq '^net.ipv4.conf.all.accept_source_route\s*=\s*0\b' && test1=remediated
	fi
	# Check net.ipv4.conf.all.accept_source_route in sysctl conf files
	echo "- $(date +%d-%b-%Y' '%T) - Checking net.ipv4.conf.all.accept_source_route in sysctl conf files" | tee -a "$LOG" 2>> "$ELOG"
	if grep -Elqs "^\s*net\.ipv4\.conf\.all\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf; then
		test2=passed
	else
		echo "- $(date +%d-%b-%Y' '%T) - Remediating net.ipv4.conf.all.accept_source_route in sysctl conf files" | tee -a "$LOG" 2>> "$ELOG"
		grep -Els "net\.ipv4\.conf\.all\.accept_source_route\s*=" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf | while read -r filename; do
			sed -ri 's/^\s*(#\s*)?(net\.ipv4\.conf\.all\.accept_source_route\s*=\s*)(\S+)(.*)?$/\20 # Modified by CIS-LBK/' "$filename"
		done
		if ! grep -Elqs "^\s*net\.ipv4\.conf\.all\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf; then
			echo "net.ipv4.conf.all.accept_source_route = 0" >> /etc/sysctl.d/cis_sysctl.conf
		fi
		grep -Elqs "^\s*net\.ipv4\.conf\.all\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf && test2=remediated
	fi

	# Check net.ipv4.conf.default.accept_source_route
	# Check sysctl net.ipv4.conf.default.accept_source_route in the running config
	echo "- $(date +%d-%b-%Y' '%T) - Checking sysctl net.ipv4.conf.default.accept_source_route in the running config" | tee -a "$LOG" 2>> "$ELOG"
	if sysctl net.ipv4.conf.default.accept_source_route | grep -Eq '^net.ipv4.conf.default.accept_source_route\s*=\s*0\b'; then
		test3=passed
	else
		echo "- $(date +%d-%b-%Y' '%T) - Remediating net.ipv4.conf.default.accept_source_route in the running config" | tee -a "$LOG" 2>> "$ELOG"
		sysctl -w net.ipv4.conf.default.accept_source_route=0
		sysctl -w net.ipv4.route.flush=1
		sysctl net.ipv4.conf.default.accept_source_route | grep -Eq '^net.ipv4.conf.default.accept_source_route\s*=\s*0\b' && test3=remediated
	fi
	# Check net.ipv4.conf.default.accept_source_route in sysctl conf files
	echo "- $(date +%d-%b-%Y' '%T) - Checking net.ipv4.conf.default.accept_source_route in sysctl conf files" | tee -a "$LOG" 2>> "$ELOG"
	if grep -Elqs "^\s*net\.ipv4\.conf\.default\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf; then
		test4=passed
	else
		echo "- $(date +%d-%b-%Y' '%T) - Remediating net.ipv4.conf.default.accept_source_route in sysctl conf files" | tee -a "$LOG" 2>> "$ELOG"
		grep -Els "net\.ipv4\.conf\.default\.accept_source_route\s*=" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf | while read -r filename; do
			sed -ri 's/^\s*(#\s*)?(net\.ipv4\.conf\.default\.accept_source_route\s*=\s*)(\S+)(.*)?$/\20 # Modified by CIS-LBK/' "$filename"
		done
		if ! grep -Elqs "^\s*net\.ipv4\.conf\.default\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf; then
			echo "net.ipv4.conf.default.accept_source_route = 0" >> /etc/sysctl.d/cis_sysctl.conf
		fi
		grep -Elqs "^\s*net\.ipv4\.conf\.default\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf && test4=remediated
	fi

	# Check if IPv6 is enabled on the system
	[ -z "$no_ipv6" ] && ipv6_chk
	if [ "$no_ipv6" = yes ]; then
		echo "- $(date +%d-%b-%Y' '%T) - IPv6 is disabled, skipping IPv6 checks" | tee -a "$LOG" 2>> "$ELOG"
		test5=passed test6=passed test7=passed test8=passed
	else
		# Check net.ipv6.conf.all.accept_source_route
		# Check sysctl net.ipv6.conf.all.accept_source_route in the running config
		echo "- $(date +%d-%b-%Y' '%T) - Checking sysctl net.ipv6.conf.all.accept_source_route in the running config" | tee -a "$LOG" 2>> "$ELOG"
		if sysctl net.ipv6.conf.all.accept_source_route | grep -Eq '^net.ipv6.conf.all.accept_source_route\s*=\s*0\b'; then
			test5=passed
		else
			echo "- $(date +%d-%b-%Y' '%T) - Remediating net.ipv6.conf.all.accept_source_route in the running config" | tee -a "$LOG" 2>> "$ELOG"
			sysctl -w net.ipv6.conf.all.accept_source_route=0
			sysctl -w net.ipv6.route.flush=1
			sysctl net.ipv6.conf.all.accept_source_route | grep -Eq '^net.ipv6.conf.all.accept_source_route\s*=\s*0\b' && test5=remediated
		fi
		# Check net.ipv6.conf.all.accept_source_route in sysctl conf files
		echo "- $(date +%d-%b-%Y' '%T) - Checking net.ipv6.conf.all.accept_source_route in sysctl conf files" | tee -a "$LOG" 2>> "$ELOG"
		if grep -Elqs "^\s*net\.ipv6\.conf\.all\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf; then
			test6=passed
		else
			echo "- $(date +%d-%b-%Y' '%T) - Remediating net.ipv6.conf.all.accept_source_route in sysctl conf files" | tee -a "$LOG" 2>> "$ELOG"
			grep -Els "net\.ipv6\.conf\.all\.accept_source_route\s*=" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf | while read -r filename; do
				sed -ri 's/^\s*(#\s*)?(net\.ipv6\.conf\.all\.accept_source_route\s*=\s*)(\S+)(.*)?$/\20 # Modified by CIS-LBK/' "$filename"
			done
			if ! grep -Elqs "^\s*net\.ipv6\.conf\.all\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf; then
				echo "net.ipv6.conf.all.accept_source_route = 0" >> /etc/sysctl.d/cis_sysctl.conf
			fi
			grep -Elqs "^\s*net\.ipv6\.conf\.all\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf && test6=remediated
		fi

		# Check net.ipv6.conf.default.accept_source_route
		# Check sysctl net.ipv6.conf.default.accept_source_route in the running config
		echo "- $(date +%d-%b-%Y' '%T) - Checking sysctl net.ipv6.conf.default.accept_source_route in the running config" | tee -a "$LOG" 2>> "$ELOG"
		if sysctl net.ipv6.conf.default.accept_source_route | grep -Eq '^net.ipv6.conf.default.accept_source_route\s*=\s*0\b'; then
			test7=passed
		else
			echo "- $(date +%d-%b-%Y' '%T) - Remediating net.ipv6.conf.default.accept_source_route in the running config" | tee -a "$LOG" 2>> "$ELOG"
			sysctl -w net.ipv6.conf.default.accept_source_route=0
			sysctl -w net.ipv4.route.flush=1
			sysctl net.ipv6.conf.default.accept_source_route | grep -Eq '^net.ipv6.conf.default.accept_source_route\s*=\s*0\b' && test7=remediated
		fi
		# Check net.ipv6.conf.default.accept_source_route in sysctl conf files
		echo "- $(date +%d-%b-%Y' '%T) - Checking net.ipv6.conf.default.accept_source_route in sysctl conf files" | tee -a "$LOG" 2>> "$ELOG"
		if grep -Elqs "^\s*net\.ipv6\.conf\.default\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf; then
			test8=passed
		else
			echo "- $(date +%d-%b-%Y' '%T) - Remediating net.ipv6.conf.default.accept_source_route in sysctl conf files" | tee -a "$LOG" 2>> "$ELOG"
			grep -Els "net\.ipv6\.conf\.default\.accept_source_route\s*=" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf | while read -r filename; do
				sed -ri 's/^\s*(#\s*)?(net\.ipv6\.conf\.default\.accept_source_route\s*=\s*)(\S+)(.*)?$/\20 # Modified by CIS-LBK/' "$filename"
			done
			if ! grep -Elqs "^\s*net\.ipv6\.conf\.default\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf; then
				echo "net.ipv6.conf.default.accept_source_route = 0" >> /etc/sysctl.d/cis_sysctl.conf
			fi
			grep -Elqs "^\s*net\.ipv6\.conf\.default\.accept_source_route\s*=\s*0\b" /etc/sysctl.conf /etc/sysctl.d/*.conf /usr/lib/sysctl.d/*.conf /run/sysctl.d/*.conf && test8=remediated
		fi
	fi

	# Check status of tests
	if [ -n "$test1" ] && [ -n "$test2" ] && [ -n "$test3" ] && [ -n "$test4" ] && [ -n "$test5" ] && [ -n "$test6" ] && [ -n "$test7" ] && [ -n "$test8" ]; then
		if [ "$test1" = passed ] && [ "$test2" = passed ] && [ "$test3" = passed ] && [ "$test4" = passed ] && [ "$test5" = passed ] && [ "$test6" = passed ] && [ "$test7" = passed ] && [ "$test8" = passed ]; then
			test=passed
		else
			test=remediated
		fi
	fi
	
	# Set return code and return
	case "$test" in
		passed)
			echo "Recommendation \"$RNA\" No remediation required" | tee -a "$LOG" 2>> "$ELOG"
			return "${XCCDF_RESULT_PASS:-101}"
			;;
		remediated)
			echo "Recommendation \"$RNA\" successfully remediated" | tee -a "$LOG" 2>> "$ELOG"
			return "${XCCDF_RESULT_PASS:-103}"
			;;
		manual)
			echo "Recommendation \"$RNA\" requires manual remediation" | tee -a "$LOG" 2>> "$ELOG"
			return "${XCCDF_RESULT_FAIL:-106}"
			;;
		*)
			echo "Recommendation \"$RNA\" remediation failed" | tee -a "$LOG" 2>> "$ELOG"
			return "${XCCDF_RESULT_FAIL:-102}"
			;;
	esac
}